#
# spec file for package product-builder
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Summary:        SUSE Product Builder
License:        GPL-2.0-only
Group:          System/Management
URL:            http://github.com/openSUSE/product-builder
Name:           product-builder
Conflicts:      kiwi
Conflicts:      kiwi-instsource
Version:        1.4.14
Release:        1.6
Provides:       kiwi-schema = 6.2
Source:         product-builder-%version.tar.xz

Requires:       libxslt
Requires:       perl >= %{perl_version}
Requires:       perl-Class-Singleton
Requires:       perl-Config-IniFiles >= 2.49
Requires:       perl-File-Slurp
Requires:       perl-JSON
Requires:       perl-Readonly
Requires:       perl-XML-LibXML
Requires:       perl-XML-LibXML-Common
Requires:       perl-XML-SAX
Requires:       perl-libwww-perl

Provides:       kiwi-packagemanager:instsource
Provides:       system-packages:kiwi-product
%if 0%{?suse_version}
Requires:       build
%else
Requires:       obs-build
%global debug_package %{nil}
%endif
Requires:       checkmedia
Requires:       inst-source-utils
Requires:       mkisofs
Requires:       product-builder-plugin
%ifarch %ix86 x86_64
Requires:       syslinux
%endif

%description
The SUSE product builder, builds product media (CD/DVD) for
the SUSE product portfolio. Based on kiwi perl implementation.

To be used only for product medias for Leap 15 and SLE 15.

%prep
%setup -q

%build
test -e /.buildenv && . /.buildenv
make CFLAGS="%{optflags}"

%install
make buildroot="%{buildroot}" \
    doc_prefix="%{buildroot}/%{_defaultdocdir}" \
    man_prefix="%{buildroot}/%{_mandir}" \
    install
./.version >"%{buildroot}/%{_datadir}/kiwi/.revision"

%if 0%{?is_opensuse}
mv %{buildroot}%{_bindir}/product-builder{.pl,}
%else
# install SLE wrapper as entry point. It doesn't really harm as the
# build flavor detected is very specific, but to avoid waste...
ln -s product-builder-sle.sh %{buildroot}%{_bindir}/product-builder
%endif

%files
%dir %{_datadir}/kiwi
%license LICENSE
%{_datadir}/kiwi/.revision
%{_datadir}/kiwi/metadata
%{_datadir}/kiwi/modules
%{_datadir}/kiwi/xsl
%{_bindir}/product-builder*

%changelog
* Thu Jul 27 2023 Adrian Schröter <adrian@suse.de>
- 1.4.14
  * Introduce DOWNLOAD_MIRROR_POLICY option, enabled by default!
    => can lead to build failures on inconsistent package build
    states
  * Joliet format only on main medium
* Fri Mar 24 2023 Adrian Schröter <adrian@suse.de>
- 1.4.13
  * fix version compare logic, using the newest candidate now
* Wed Dec 14 2022 Adrian Schröter <adrian@suse.de>
- 1.4.12
  * RedHat media support
  * SLSA provenance file support
  * support to set DVD volumeid manual
  * fix hybrid ISO creation
  * support modulemd filtering
* Mon Sep 27 2021 Adrian Schröter <adrian@suse.de>
- 1.4.6
  * fixed package tracking regression
* Fri Sep 17 2021 Adrian Schröter <adrian@suse.de>
- 1.4.4
  * put all candidates of all modules to the medium
  * fixed architecture handling in version priority mode
* Mon Sep  6 2021 Adrian Schröter <adrian@suse.de>
- 1.4.2
  * support newest rpm version mode (no repository priority)
  * helpful error message when exact version is required
* Mon Jun 28 2021 Adrian Schröter <adrian@suse.de>
- 1.3.4
  * fix collecting of source rpms when multiple different
    binary versions were used
* Mon Mar 15 2021 Adrian Schröter <adrian@suse.de>
- 1.3.3
  * armv7l support
* Mon Feb  8 2021 Adrian Schröter <adrian@suse.de>
- 1.3.2
  * RISC-V support
* Mon Sep 14 2020 Adrian Schröter <adrian@suse.de>
- 1.3.1
  * include license information in report files
    (do not use this on OBS 2.10 or before)
* Tue Apr 21 2020 Adrian Schröter <adrian@suse.de>
- 1.3.0
  * fail when plugins fail
* Wed Apr 15 2020 Adrian Schröter <adrian@suse.de>
- 1.2.10
  * disable -chrp-boot option for ppc64le (bsc#1169420)
* Fri Feb 28 2020 Adrian Schröter <adrian@suse.de>
- 1.2.9
  * fix "multiple kiwi files" error for Full media
* Wed Feb 26 2020 Adrian Schröter <adrian@suse.de>
- 1.2.8
  * keep kwd file in SLE Full media wrapper (bsc#1164670)
* Wed Feb  5 2020 Adrian Schröter <adrian@suse.de>
- 1.2.7
  * Fix possible partition misallignment (bsc#1162531)
* Thu Dec 12 2019 Frederic Crozat <fcrozat@suse.com>
- 1.2.6
  * Fix SLE wrapper for new Package DVD name.
* Wed Sep 18 2019 Stephan Kulow <coolo@suse.com>
- 1.2.5
  * Fix SLE wrapper to take the proper architecture for packages DVD (jsc#SLE-8271)
* Mon Sep 16 2019 Stephan Kulow <coolo@suse.com>
- 1.2.4
  * add SLE wrapper to prepare modules for packages dvd (jsc#SLE-8271)
  * smaller perl fixes
* Fri Sep 13 2019 Adrian Schröter <adrian@suse.de>
- 1.2.3
  handle multiple packages with same name but different version/release in one repo.
  bsc#1150238
* Tue Jul 16 2019 Adrian Schröter <adrian@suse.de>
- 1.2.2
  * track provided cpeid of products
* Wed Jan 16 2019 Adrian Schröter <adrian@suse.de>
- 1.2.1
  * Use RPi hybrid mode on aarch64 always (no config needed anymore)
* Fri Aug 24 2018 Adrian Schröter <adrian@suse.de>
- 1.2.0
  * Add special RPi hybrid mode
* Wed Jun  6 2018 adrian@suse.de
- 1.1.3
  * Another fix needed for hybrid media on x86_64
* Tue Jun  5 2018 adrian@suse.de
- 1.1.2
  * Do not generate Apple partion on ppc64le anymore
  * Allow to build medias without meta packages again
* Mon Jun  4 2018 adrian@suse.de
- 1.1.1
  * fix EFI boot sort order
- drop factory skelcd hack (accept_old_meta_package.patch)
* Tue May 29 2018 adrian@suse.de
- 1.1.0
  * fixed handling of metapackages with multiple lines for one package
    filtered via required architecture
  * execute mk_listings when configured (bsc#1094929)
  + drop promo / live boot code
  * Add riscv64 architecture
* Tue Apr 24 2018 adrian@suse.de
- 1.0.9
  * have a different medium name in media.?/media for debug and
    source medium
* Mon Mar 26 2018 adrian@suse.de
- 1.0.8
  * support skelcd with NET subfolder
* Tue Mar 13 2018 coolo@suse.com
- 1.0.7
  * fix ppc64le (related to bsc#1084893)
- align with SLE changes file (add accept_old_meta_package.patch)
* Thu Mar  8 2018 adrian@suse.de
- 1.0.6
  * fixed platform ID for EFI boot (bsc#1081739)
- fix dependencies to mkisofs
- using spec file from git now
* Fri Mar  2 2018 adrian@suse.de
- 1.0.5
  * use mkisofs instead of unmaintained wodim
* Fri Feb 16 2018 adrian@suse.de
- 1.0.4
  * Fix ChangeLog file generation
* Fri Jan 19 2018 adrian@suse.de
- 1.0.3
  * Adapt to changed -debuginfo-32bit -> -32bit-debuginfo name scheme in SLE 15
    (incompatible change)
* Tue Jan 16 2018 adrian@suse.de
- 1.0.2
  * drop IA64 support and fix corner case for qemu-x86-debug* packages
* Thu Jan 11 2018 adrian@suse.de
- 1.0.1
  * allow to call mk_changelog again (bsc#1050404)
    default is still off
* Fri Dec  1 2017 adrian@suse.de
- tag it as 1.0
- fix UEFI secure boot (bsc#939456)
* Tue Nov 21 2017 dimstar@opensuse.org
- Apply accept_old_meta_package.patch also in case prjmeta has a
  skelcd_compat variable defined. This allows us to change
  suse_version while still not being able to migrate to the new
  product converter/builder for Tumbleweed.
* Fri Oct  6 2017 adrian@suse.de
- patch README.BETA again
* Fri Sep 22 2017 adrian@suse.de
- bring back media.?/media file
- drop media.?/build instead
- building separate media is an explicit setting now
* Fri Sep 15 2017 adrian@suse.de
- copy .treeinfo for virt-installer
* Tue Sep 12 2017 adrian@suse.de
- detect all products which got put on media
* Tue Sep  5 2017 adrian@suse.de
- Add accept_old_meta_package.patch: temporarily accept metadata
  in /CD1 for tumbleweed to ease migration.
* Mon Aug 21 2017 adrian@suse.de
- bring back media.1/products file
  => means that pure repomd data is not anymore enough for YaST
    installer
* Mon Aug 21 2017 adrian@suse.de
- fix metapackage unpack loop
* Wed Aug  9 2017 ro@suse.de
- only use x86 boot image on s390/s390x if it exists
- also, on s390/s390x if we have a x86_64 image, make that bootable
- enforce default to abort on missing packages
* Tue Aug  8 2017 adrian@suse.de
- always exit on error (bsc#1052017)
* Tue Jul 11 2017 adrian@suse.de
- add Provides system-packages:kiwi-product
- temporary compat code for /CD? directories in meta packages
* Tue Jun 27 2017 adrian@suse.de
- install missing file for generating PowerPC medias (bsc#1046114)
* Fri Jun 23 2017 adrian@suse.de
- fix unpacking of meta packages and plugin execution
* Wed May 24 2017 adrian@suse.de
- adapt path of meta packages to /usr/lib/skeldcd/CD?  (bsc#1031335)
* Fri Apr 28 2017 jengelh@inai.de
- Stop using old RPM shell vars
* Tue Apr 11 2017 adrian@suse.de
- initial package based on kiwi 7, first attempt for Leap 15
